@@ -2,6 +2,6 @@ import importlib.metadata
 
 __version__ = importlib.metadata.version("strangeworks-annealing")
 
-from .problem import qubo_energy, load_problem
-from .solver import get_solvers, select_solver
+from .problem import load_problem, qubo_energy
 from .sampler import SWDWaveSampler
+from .solver import get_solvers, select_solver
